@@ -36,48 +36,38 @@ class Field(Validatable):
 
     def __init__(self) -> None:
         """
-        Initializes an empty field.
+        Initializes a field.
         """
         Validatable.__init__(self)
         Debug(self, ": Init", init=True)
 
+        # Parameters
+        self.type = 0
+        self._distance_limit = 0
+        self._length_scale = 0
+
+        # Results
         self._total_calculations: int = 0
         self._total_skipped_calculations: int = 0
         self._vectors: np.ndarray = np.array([])
 
-        self._backend_type = 0
-        self._field_type = 0
-        self._distance_limit = 0
-        self._length_scale = 0
-
     def set(
             self,
-            backend_type: int,
-            field_type: int,
+            type: int,
             distance_limit: float,
             length_scale: float
     ):
         """
         Sets the parameters.
 
-        @param backend_type: Backend type
-        @param field_type: Field type
+        @param type: Field type
         @param distance_limit: Distance limit (mitigating divisions by zero)
         @param length_scale: Length scale (m)
         """
-        self._backend_type = backend_type
-        self._field_type = field_type
+        self.type = type
         self._distance_limit = distance_limit
         self._length_scale = length_scale
 
-    def get_type(self) -> int:
-        """
-        Gets field type.
-
-        @return: Field type
-        """
-        return self._field_type
-
     def get_units(self, show_gauss=False) -> Tuple[str, float]:
         """
         Gets field units.
@@ -87,41 +77,14 @@ class Field(Validatable):
         """
         if show_gauss:
             return {
-                FIELD_TYPE_A: "Gs·m",    # Gauss · meter
-                FIELD_TYPE_B: "Gs"       # Gauss
-            }.get(self._field_type, ""), 1e4
+                FIELD_TYPE_A: "G·m",    # Gauss · meter
+                FIELD_TYPE_B: "G"       # Gauss
+            }.get(self.type, ""), 1e4
         else:
             return {
-                FIELD_TYPE_A: "T·m",     # Tesla · meter
-                FIELD_TYPE_B: "T"        # Tesla
-            }.get(self._field_type, ""), 1e0
-
-    @require_valid
-    def get_vectors(self) -> np.ndarray:
-        """
-        Gets field vectors. (The selected field type determined which field was calculated.)
-
-        @return: Ordered list of 3D vectors (field vectors & corresponding sampling volume points have the same indices)
-        """
-        return self._vectors
-
-    @require_valid
-    def get_total_calculations(self) -> int:
-        """
-        Gets total number of calculations.
-
-        @return: Total number of calculations
-        """
-        return self._total_calculations
-
-    @require_valid
-    def get_total_skipped_calculations(self) -> int:
-        """
-        Gets total number of skipped calculations.
-
-        @return: Total number of skipped calculations
-        """
-        return self._total_skipped_calculations
+                FIELD_TYPE_A: "T·m",    # Tesla · meter
+                FIELD_TYPE_B: "T"       # Tesla
+            }.get(self.type, ""), 1e0
 
     # ------------------------------------------------------------------------------------------------------------------
 
@@ -131,7 +94,8 @@ class Field(Validatable):
             wire: Wire,
             sampling_volume: SamplingVolume,
             progress_callback: Callable,
-            num_cores: int
+            num_cores: int,
+            backend_type: int
     ) -> bool:
         """
         Recalculates field vectors.
@@ -140,43 +104,44 @@ class Field(Validatable):
         @param sampling_volume: Sampling volume
         @param progress_callback: Progress callback
         @param num_cores: Number of cores to use for multiprocessing
+        @param backend_type: Backend type
         @return: True if successful, False if interrupted (CUDA backend currently not interruptable)
         """
         Debug(self, ".recalculate()")
 
         # Compute the current elements.
-        current_elements = wire.get_elements()
+        current_elements = wire.elements
 
-        if self._backend_type == BACKEND_TYPE_JIT:
+        if backend_type == BACKEND_TYPE_JIT:
 
             # Initialize Biot-Savart JIT backend
             backend = Backend_JIT(
-                self._field_type,
-                self._distance_limit,
-                self._length_scale,
-                wire.get_dc(),
-                current_elements,
-                sampling_volume.get_points(),
-                sampling_volume.get_permeabilities(),
-                progress_callback
+                field_type=self.type,
+                distance_limit=self._distance_limit,
+                length_scale=self._length_scale,
+                dc=wire.dc,
+                current_elements=current_elements,
+                sampling_volume_points=sampling_volume.points,
+                sampling_volume_permeabilities=sampling_volume.permeabilities,
+                progress_callback=progress_callback
             )
 
             # Fetch result using Biot-Savart JIT backend
             set_num_threads(num_cores)
             backend_result = backend.get_result()
 
-        elif self._backend_type == BACKEND_TYPE_CUDA:
+        elif backend_type == BACKEND_TYPE_CUDA:
 
             # Initialize Biot-Savart CUDA backend
             backend = Backend_CUDA(
-                self._field_type,
-                self._distance_limit,
-                self._length_scale,
-                wire.get_dc(),
-                current_elements,
-                sampling_volume.get_points(),
-                sampling_volume.get_permeabilities(),
-                progress_callback
+                field_type=self.type,
+                distance_limit=self._distance_limit,
+                length_scale=self._length_scale,
+                dc=wire.dc,
+                current_elements=current_elements,
+                sampling_volume_points=sampling_volume.points,
+                sampling_volume_permeabilities=sampling_volume.permeabilities,
+                progress_callback=progress_callback
             )
 
             # Fetch result using Biot-Savart CUDA backend
@@ -185,7 +150,7 @@ class Field(Validatable):
 
         else:
 
-            Debug(self, f".recalculate(): ERROR: No such backend: {self._backend_type}", error=True)
+            Debug(self, f".recalculate(): ERROR: No such backend: {backend_type}", error=True)
             return False
 
         # Handle interrupt
@@ -197,13 +162,51 @@ class Field(Validatable):
         self._vectors = backend_result[2]
 
         # Sanity check
-        expected_total_calculations = len(current_elements) * sampling_volume.get_points_count()
+        expected_total_calculations = len(current_elements) * sampling_volume.points_count
         if expected_total_calculations != self._total_calculations:
             Assert_Dialog(False, "ERROR: Unexpected number of calculations – Backend seems to be buggy")
             return False
 
         return True
 
+    @property
+    @require_valid
+    def vectors(self) -> np.ndarray:
+        """
+        Gets field vectors. (The selected field type determined which field was calculated.)
+
+        @return: Ordered list of 3D vectors (field vectors & corresponding sampling volume points have the same indices)
+        """
+        return self._vectors
+
+    @property
+    @require_valid
+    def vectors_count(self) -> int:
+        """
+        @return: Number of field vectors
+        """
+        return len(self._vectors)
+
+    @property
+    @require_valid
+    def total_calculations(self) -> int:
+        """
+        Gets total number of calculations.
+
+        @return: Total number of calculations
+        """
+        return self._total_calculations
+
+    @property
+    @require_valid
+    def total_skipped_calculations(self) -> int:
+        """
+        Gets total number of skipped calculations.
+
+        @return: Total number of skipped calculations
+        """
+        return self._total_skipped_calculations
+
     # ------------------------------------------------------------------------------------------------------------------
 
     @staticmethod
