@@ -244,7 +244,7 @@ class Model:
                 do_parameters=True
             )
 
-            self.field.set(field_type=field_type, *args, **kwargs)
+            self.field.set(type=field_type, *args, **kwargs)
 
     def set_metric(
             self,
@@ -298,7 +298,7 @@ class Model:
         """
         Debug(self, ".calculate_wire()")
         self.invalidate(do_sampling_volume=True, do_field=True, do_metric=True)
-        return self.wire.recalculate(progress_callback)
+        return self.wire.recalculate(progress_callback=progress_callback)
 
     def calculate_sampling_volume(self, progress_callback: Callable) -> bool:
         """
@@ -309,19 +309,26 @@ class Model:
         """
         Debug(self, ".calculate_sampling_volume()")
         self.invalidate(do_field=True, do_metric=True)
-        return self.sampling_volume.recalculate(progress_callback)
+        return self.sampling_volume.recalculate(progress_callback=progress_callback)
 
-    def calculate_field(self, progress_callback: Callable, num_cores: int) -> bool:
+    def calculate_field(self, progress_callback: Callable, num_cores: int, backend_type: int) -> bool:
         """
         Calculates the field.
 
         @param progress_callback: Progress callback
         @param num_cores: Number of CPU cores to use
+        @param backend_type: Backend type
         @return: True if successful, False if interrupted
         """
         Debug(self, f".calculate_field(num_cores={num_cores})")
         self.invalidate(do_metric=True)
-        return self.field.recalculate(self.wire, self.sampling_volume, progress_callback, num_cores)
+        return self.field.recalculate(
+            wire=self.wire,
+            sampling_volume=self.sampling_volume,
+            progress_callback=progress_callback,
+            num_cores=num_cores,
+            backend_type=backend_type
+        )
 
     def calculate_metric(self, progress_callback: Callable) -> bool:
         """
@@ -331,7 +338,11 @@ class Model:
         @return: True (currently non-interruptable)
         """
         Debug(self, ".calculate_metric()")
-        return self.metric.recalculate(self.sampling_volume, self.field, progress_callback)
+        return self.metric.recalculate(
+            sampling_volume=self.sampling_volume,
+            field=self.field,
+            progress_callback=progress_callback
+        )
 
     def calculate_parameters(self, progress_callback: Callable) -> bool:
         """
@@ -341,7 +352,12 @@ class Model:
         @return: True (currently non-interruptable)
         """
         Debug(self, ".calculate_parameters()")
-        return self.parameters.recalculate(self.wire, self.sampling_volume, self.field, progress_callback)
+        return self.parameters.recalculate(
+            wire=self.wire,
+            sampling_volume=self.sampling_volume,
+            field=self.field,
+            progress_callback=progress_callback
+        )
 
     # ------------------------------------------------------------------------------------------------------------------
 
@@ -353,6 +369,7 @@ class Model:
 
         self.gui.sidebar_left.wire_widget.update()
         self.gui.menu.wire_menu.update()
+        self.gui.vispy_canvas.redraw()
 
     def on_sampling_volume_valid(self) -> None:
         """
@@ -363,6 +380,7 @@ class Model:
         self.gui.sidebar_left.sampling_volume_widget.update()
         self.gui.sidebar_right.display_widget.update()
         self.gui.sidebar_right.display_widget.prevent_excessive_field_labels(choice=False)
+        self.gui.vispy_canvas.redraw()
 
     def on_field_valid(self) -> None:
         """
@@ -371,6 +389,7 @@ class Model:
         Debug(self, ".on_field_valid()")
 
         self.gui.sidebar_right.field_widget.update()
+        self.gui.vispy_canvas.redraw()
 
     def on_metric_valid(self) -> None:
         """
@@ -381,6 +400,7 @@ class Model:
         Debug(self, ".on_metric_valid()")
 
         self.gui.sidebar_right.metric_widget.update()
+        self.gui.vispy_canvas.redraw()
 
     def on_parameters_valid(self) -> None:
         """
@@ -389,6 +409,7 @@ class Model:
         Debug(self, ".on_parameters_valid()")
 
         self.gui.sidebar_right.parameters_widget.update()
+        self.gui.vispy_canvas.redraw()
 
     # ------------------------------------------------------------------------------------------------------------------
 
