@@ -224,30 +224,27 @@ class Wire_Presets:
         return np.array(wire_points)
 
     # Preset: A phase-jumping toroidal loop: 8 turns.
-    # noinspection PyUnresolvedReferences
     PhaseJumpingToroidalLoop8 = {
         "id": "Phase-jumping Toroidal Loop: 8 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=8,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=8
         )
     }
     # Preset: A phase-jumping toroidal loop: 32 turns.
-    # noinspection PyUnresolvedReferences
     PhaseJumpingToroidalLoop16 = {
         "id": "Phase-jumping Toroidal Loop: 16 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=16,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=16
         )
     }
     # Preset: A phase-jumping toroidal loop: 32 turns.
-    # noinspection PyUnresolvedReferences
     PhaseJumpingToroidalLoop32 = {
         "id": "Phase-jumping Toroidal Loop: 32 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=32,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=32
@@ -255,10 +252,9 @@ class Wire_Presets:
     }
 
     # Preset: A toroidal loop: 8 turns.
-    # noinspection PyUnresolvedReferences
     ToroidalLoop8 = {
         "id": "Toroidal Loop: 8 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=1,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=8
@@ -266,10 +262,9 @@ class Wire_Presets:
     }
 
     # Preset: A toroidal loop: 16 turns.
-    # noinspection PyUnresolvedReferences
     ToroidalLoop16 = {
         "id": "Toroidal Loop: 16 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=1,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=16
@@ -277,10 +272,9 @@ class Wire_Presets:
     }
 
     # Preset: A toroidal loop: 32 turns.
-    # noinspection PyUnresolvedReferences
     ToroidalLoop32 = {
         "id": "Toroidal Loop: 32 turns",
-        "points": get_phase_jumping_toroidal_loop.__func__(
+        "points": get_phase_jumping_toroidal_loop.__func__(  # type: ignore
             n_points=640, n_phase_jumps=1,
             toroidal_radius=1, poloidal_radius=.5,
             toroidal_freq=1, poloidal_freq=32
